<!-- -*- html -*- -->
<h3>Support</h3>
<li><a href="trouble.html">Troubleshooting</a>
<li><a href="http://tmda.net/faq.cgi" TARGET="Resource Window">FAQ</a>
<li><a href="bugs.html">Bugs &amp; Patches</a>
<li><a href="http://tmda.net/lists/listinfo/" TARGET="Resource Window">Mailing Lists</a>
<li><a href="http://mla.libertine.org/" TARGET="Resource Window">List Archive</a> 
<li><a href="resources.html">External Resources</a>
